==> pvfs-kernel-0.9.0-pre6.tgz: pvfs-kernel-0.9.0-pre6/pvfsdev.h <==
#ifndef __PVFSDEV_H
#define __PVFSDEV_H

/*
 * copyright (c) 1999 Rob Ross and Phil Carns, all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or
 * modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.clemson.edu
 *           Phil Carns  pcarns@parl.clemson.edu
 */


/******************************************
 * These are the pvfsdev functions exported to the kernel
 * to enable messaging with the user level daemon.
 ******************************************/

/* this allows the kernel to send a single upcall through the pvfsdev
 * device- will wait for a returning downcall only if the flag is set */
int pvfsdev_enqueue(struct pvfs_upcall *in_upcall, struct pvfs_downcall
	*out_upcall, int waitflag);

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 * End:
 */

#endif /* __PVFSDEV_H */

==> pvfs-kernel-0.9.3-pre2.tgz: pvfs-kernel-0.9.3-pre2/pvfsdev.h <==
#ifndef __PVFSDEV_H
#define __PVFSDEV_H

/*
 * copyright (c) 1999 Rob Ross and Phil Carns, all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or
 * modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.clemson.edu
 *           Phil Carns  pcarns@parl.clemson.edu
 */


/******************************************
 * These are the pvfsdev functions exported to the kernel
 * to enable messaging with the user level daemon.
 ******************************************/

/* this allows the kernel to send a single upcall through the pvfsdev
 * device- will wait for a returning downcall only if the flag is set */
int pvfsdev_enqueue(struct pvfs_upcall *in_upcall, 
						  struct pvfs_downcall *out_upcall);

int pvfsdev_enqueue_noresponse(struct pvfs_upcall *in_upcall);

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 * End:
 */

#endif /* __PVFSDEV_H */
